==> mariadb_10.11.14.orig.tar.gz: mariadb-10.11.14/CONTRIBUTING.md <==
# How to contribute

MariaDB Server has a vibrant community contributing in a wide range of areas. There are many valuable ways you can contribute to MariaDB.

### Engage online with other community members
---
-   [MariaDB on Zulip](https://mariadb.zulipchat.com/)
-   [maria-developers mailing list](http://launchpad.net/~maria-developers)
-   [maria-discuss mailing list](http://launchpad.net/~maria-discuss)
-   [maria-docs mailing list](http://launchpad.net/~maria-docs)
-   The MariaDB Foundation and MariaDB Corporation have a presence on Reddit, Twitter and Facebook. See the  [social media page](https://mariadb.com/kb/en/mariadb/social-media/).

### Help document MariaDB
----
-   Contribute towards [documenting MariaDB Server](https://mariadb.com/kb/en/meta/writing-editing-library-articles/)  and its ecosystem by adding new content or improving existing content.
-   [Translate](https://mariadb.com/kb/en/meta/translating-library-articles/)  existing documentation.

### Help debug and develop MariaDB
-----
-   [Report bugs](https://jira.mariadb.org/)
-   Test development versions
-   Write code to fix bugs or develop new features (see  [Getting Started for Developers](https://mariadb.org/getting-started-for-developers)).See also [list of beginner friendly tasks](https://jira.mariadb.org/browse/MDEV-15736?jql=resolution%20%3D%20Unresolved%20AND%20labels%20%3D%20beginner-friendly%20ORDER%20BY%20updated%20DESC)
-   Help with code quality control
-   Participate in packaging for different Linux distributions

### Sponsor or donate
---
You’re very welcome to support MariaDB Server as an individual, or talk your company into joining the Foundation as a sponsoring member. See the  [Sponsor page](https://mariadb.org/donate/).

### Events, meetups and conferences
---
-   Attend an event
    -   [Events and Conferences page](https://mariadb.org/events/)
    -   [mariadb.meetup.com](http://mariadb.meetup.com/)

### Live QA for beginner contributors
----
MariaDB has a dedicated time each week when we answer new contributor questions live on Zulip.
From 8:00 to 10:00 UTC on Mondays, and 10:00 to 12:00 UTC on Thursdays, anyone can ask any questions they’d like,
and a live developer will be available to assist.
New contributors can ask questions any time, but we will provide immediate feedback during that interval.

### Additional resources
----
 - [MariaDB Foundation ](https://mariadb.org/)
 - [Knowledge Base](https://mariadb.com/kb/en/)

==> mariadb-10.11.16.tar.gz: mariadb-10.11.16/CONTRIBUTING.md <==
# How to contribute

MariaDB Server has a vibrant community contributing in a wide range of areas. There are many valuable ways you can contribute to MariaDB.

### Engage online with other community members
---
-   [MariaDB on Zulip](https://mariadb.zulipchat.com/)
-   [maria-developers mailing list](https://lists.mariadb.org/postorius/lists/developers.lists.mariadb.org/)
-   [maria-discuss mailing list](https://lists.mariadb.org/postorius/lists/discuss.lists.mariadb.org/)
-   [maria-docs mailing list](https://lists.mariadb.org/postorius/lists/docs.lists.mariadb.org/)
-   The MariaDB Foundation and MariaDB Corporation have a presence on Reddit, Twitter and Facebook. See the  [social media page](https://mariadb.com/docs/general-resources/community/joining-the-community).

### Help document MariaDB
----
-   Contribute towards [documenting MariaDB Server](https://mariadb.com/docs/general-resources/about/readme/contributing-documentation)  and its ecosystem by adding new content or improving existing content.
-   [Translate](https://mariadb.com/docs/general-resources/about/readme/contributing-documentation)  existing documentation.

### Help debug and develop MariaDB
-----
-   [Report bugs](https://jira.mariadb.org/)
-   Test development versions
-   Write code to fix bugs or develop new features (see  [Getting Started for Developers](https://mariadb.org/getting-started-for-developers)).See also [list of beginner friendly tasks](https://jira.mariadb.org/browse/MDEV-15736?jql=resolution%20%3D%20Unresolved%20AND%20labels%20%3D%20beginner-friendly%20ORDER%20BY%20updated%20DESC)
-   Help with code quality control
-   Participate in packaging for different Linux distributions

### Sponsor or donate
---
You’re very welcome to support MariaDB Server as an individual, or talk your company into joining the Foundation as a sponsoring member. See the  [Sponsor page](https://mariadb.org/donate/).

### Events, meetups and conferences
---
-   Attend an event
    -   [Events and Conferences page](https://mariadb.org/events/)
    -   [mariadb.meetup.com](http://mariadb.meetup.com/)

### Live QA for beginner contributors
----
MariaDB has a dedicated time each week when we answer new contributor questions live on Zulip.
From 8:00 to 10:00 UTC on Mondays, and 10:00 to 12:00 UTC on Thursdays, anyone can ask any questions they’d like,
and a live developer will be available to assist.
New contributors can ask questions any time, but we will provide immediate feedback during that interval.

### Additional resources
----
 - [MariaDB Foundation ](https://mariadb.org/)
 - [MariaDB Documentation](https://mariadb.com/docs/)
